@@ -39,7 +39,11 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
             print("pandas.errors.EmptyDataError (phone mims) : " + csv_path)
             quit()
 
-    converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f")
+    if len(df_logs_combined["HEADER_TIME_STAMP"][0].split(".")) > 1:
+        converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f")
+    else:
+        converter = lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S")
+
     df_logs_combined = df_logs_combined.dropna(subset=['HEADER_TIME_STAMP'])
     df_logs_combined.reset_index(inplace=True, drop=True)
     df_logs_combined["HEADER_TIME_STAMP"] = [x.split(" ")[0] + " " + x.split(" ")[1] for x in
@@ -51,7 +55,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     return df_logs_combined
 
 
-def find_closest_time(prompt_time, subset_time_list, min_before):
+def find_closest_time(prompt_time, subset_time_list):
     pos = bisect.bisect_left(subset_time_list, prompt_time)
     # closet_time = min(subset_time_list[max(0, i - 1): i + 2], key=lambda t: -(prompt_time - t))
 
