@@ -124,7 +124,7 @@ def extract_reprompt(df_pr_phone):
 
     df_prompt = pd.DataFrame(prompt_arrays)
     if df_prompt.shape[0] > 0:
-        df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', 'Question_Set_Prompt_Local_Time', 'UTC_Offset', "Reprompt_Num"]
+        df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', 'Prompt_Local_Time', 'UTC_Offset', "Reprompt_Num"]
 
     return df_prompt
 
@@ -176,7 +176,7 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     df_reprompt.reset_index(drop=True, inplace=True)
     Prompt_Local_Time_list = []
     for idx in df_reprompt.index:
-        prompt_local_time_timezone = df_reprompt['Question_Set_Prompt_Local_Time'][idx]
+        prompt_local_time_timezone = df_reprompt['Prompt_Local_Time'][idx]
         prompt_local_time_timezone_split = prompt_local_time_timezone.split(" ")
         prompt_local_time_timezone_split_len = len(prompt_local_time_timezone_split)
         if prompt_local_time_timezone_split_len == 3:
