@@ -96,8 +96,8 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         df_logs_combined = df_logs_combined[df_logs_combined['Date'] == prompt_date]
 
         if df_logs_combined.shape[0] == 0:
-            waking_hour = np.nan
-            sleep_hour = np.nan
+            waking_hour = "NF"
+            sleep_hour = "NF"
             print("No wake and sleep hour found for {}".format(prompt_date))
         else:
             waking_hour = list(df_logs_combined["current_wake_time"])[0]
